summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAdam Ierymenko <adam.ierymenko@gmail.com>2015-10-16 10:48:38 -0700
committerAdam Ierymenko <adam.ierymenko@gmail.com>2015-10-16 10:48:38 -0700
commit781f06ef82033cdf2488f80266b3f7a8497eba69 (patch)
treeb13bf0f8b9c8c66be79acd5c309d807bbc96c66d
parentf9f60f89d95e43e5c439bf7c86b015e1b41a2f14 (diff)
downloadinfinitytier-781f06ef82033cdf2488f80266b3f7a8497eba69.tar.gz
infinitytier-781f06ef82033cdf2488f80266b3f7a8497eba69.zip
Accept OK for confirm of HELLO or ECHO.
-rw-r--r--node/Peer.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/node/Peer.cpp b/node/Peer.cpp
index 8c5c5783..76b1d537 100644
--- a/node/Peer.cpp
+++ b/node/Peer.cpp
@@ -101,9 +101,9 @@ void Peer::received(
}
if (!pathIsConfirmed) {
- if ((verb == Packet::VERB_OK)&&(inReVerb == Packet::VERB_HELLO)) {
+ if ((verb == Packet::VERB_OK)&&((inReVerb == Packet::VERB_HELLO)||(inReVerb == Packet::VERB_ECHO))) {
- // Learn paths if they've been confirmed via a HELLO
+ // Learn paths if they've been confirmed via a HELLO or an ECHO
RemotePath *slot = (RemotePath *)0;
if (np < ZT_MAX_PEER_NETWORK_PATHS) {
// Add new path